@@ -1,6 +1,8 @@
 """NBA player model"""
 
-from typing import TypedDict, NotRequired, List
+from typing import TypedDict, List
+
+from typing_extensions import NotRequired
 
 class NbaPlayerTeamInfo(TypedDict):
     """Sub model for team info for NBA player model"""
